@@ -96,7 +96,9 @@ void bufligr(double *xr, double *rr, double *carter,
 double alea (void)
 {
     double w;
-    w = ((double) rand())/ (double)RAND_MAX;
+    GetRNGstate();
+    w = unif_rand();
+    PutRNGstate();
     return (w);
 }
 
@@ -444,7 +446,7 @@ void getpermutation (int *numero, int repet)
  * two calls returns different results (seed=clock+repet)
  ------------------------*/
 {
-    int i, n, seed;
+    int i, n;
     int *alea;
     
     n=numero[0];
@@ -460,11 +462,10 @@ void getpermutation (int *numero, int repet)
     /*-------------
      * affects random numbers in alea
      ----------------*/
-    seed = clock();
-    seed = seed + repet;
-    srand(seed);
     for (i=1;i<=n;i++) {
-	alea[i]=rand();
+ 	GetRNGstate();
+	alea[i] = unif_rand();
+	PutRNGstate();
     }
     
     trirapideint (alea , numero, 1, n);
